% umcp-thesis-draft.cls

% This is a LaTeX2e class file to comply with specifications of the 
% Thesis and Dissertation Manual of the Graduate School of the
% University of Maryland, College Park, 1995.  The manual is typically
% revised and re-published every five years.  Therefore, a revised class
% file will be required in or around the year 2000.

% IMPORTANT NOTE 
% This particular version produces a thesis that is merely a draft.
% It does not comply with the specifications.  Its purpose is to allow the
% user to print significantly shorter versions of his/her thesis during 
% the writing/editing process.  This version is compatible with single sided 
% printing.  See also: umcp-thesis-draft-2sided.cls, umcp-thesis-official.cls, 
% umcp-thesis-official-2sided.cls.

% AUTHORS
%	Andrew J. Newman
%	Department of Electrical and Computer Engineering; and
%	Institute for Systems Research
%	University of Maryland, College Park
%	newman@isr.umd.edu
%
%	This class file is based on the dissertation.sty file by
%	Pablo A. Straub, 1991, revisions by Aaron E. Naiman, the 
%	umd-thesis.cls file by Thomas J. Stone, 1995, and revisions
%	by Stefan Kehrbaum, 1997.  Some of this file is copied directly 
%	from its predecessors or contains only slight revisions.  
%	Thanks to Raadhakrishnan Poovendran for being the first to
%	use this file for his official thesis and for working out the bugs.
%	Thanks to George Kantor for being the second to use this file for
%	his official thesis and for inserting the commands for making the
%	document come out nicely for two-sided printing.

% COPYRIGHT
%	(c) Copyright 1999 by Andrew J. Newman.
%	The original copyright by Pablo A. Straub also applies, as do
%	any copyrights attached to the several subsequent revisions.
%	As with the original copyright, permission is granted to copy
%	and use this material for any purpose except direct commercial
%	advantage.

% MOTIVATION
%	The motivation is to create a LaTeX2e class file that produces
%	a thesis that adheres to specifications as set forth in the manual
%	and can be easily understood, edited, and changed.  The latter
%	reason is important, because (1) guidelines change over time, and
%	(2) the manual is not completely rigid and different users will want 
%	slightly different results.  Improvements to the predecessors to
%	this file have been made in the above areas.  
%
%	We also want to substitute LaTeX commands for the old TeX commands
%	such as \def and \gdef.
%
%	There was an additional goal, in that we also wanted the capability
%	to control all settings from the main thesis document, rather
%	than have to make changes to the class file, in order, for example,
%	to change from draft to official.  However, after achieving only
%	partial successes using various boolean flags, we abandoned that
%	effort, in favor of simply using different class files for draft,
%	official, and official-2sided.  
%
% 	In addition, we deleted all options pertaining to a Masters thesis.
%	This class file could be easily revised for a Masters thesis though.
%	We just thought that it was too unwieldy to include here.
%
%	Class umcp-thesis-draft is essentially a modified report class.

% CONTENTS
%
% 1. Class Preliminaries
% 2. Page Setup
% 3. Front Matter
%	3.1. Define parameters
%	3.2. Create front matter
%	3.3. Individual front matter sections
% 4. Headers and Formatting
% 5. Utility Commands
%	5.1. Line Spacing
%	5.2. Cross References
%	5.3. Logical
%
% This file does not deal with the back matter, except for formatting
% the header of the bibliography.  No changes are made to the standard
% LaTeX bibliography generation.  No commands are set up for handling
% a glossary, index, or curriculum vitae.  This class file can be 
% extended to handle those sections if needed.
 
%------------------------------------------------------------------------------
% 1. CLASS PRELIMINARIES
%	Set up class as a modification to the standard report class.
%------------------------------------------------------------------------------

% IDENTIFICATION

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{umcp-thesis-draft}
	      [1999/09/30 v1.0 UMCP Thesis LaTeX document class]

% REQUIRED CODE

\RequirePackage{ifthen}

% DECLARE OPTIONS 
% Draft: 10pt

\PassOptionsToClass{10pt}{report}
\PassOptionsToClass{letterpaper}{report}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}

% EXECUTE OPTIONS

\ProcessOptions

% LOAD PACKAGE
% Compatible with single sided printing

\LoadClass[openright,oneside]{report}

%------------------------------------------------------------------------------
% 2. PAGE SETUP 
%	Set margins and line spacing for thesis document.
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% COMMAND \pagesetup
%	Invoking command \pagesetup sets up the page margins and line
%	spacing according to specifications as set forth in the manual.
%	For this draft version the settings are made to fit significantly 
%	more text on each page.
%------------------------------------------------------------------------------

\newcommand{\pagesetup}{

% MARGINS
% 	We use guidelines from the UMCP thesis and dissertation manual, 1995.
% 	The margins are purposely overstated, so that variations due to 
%	printing and copying do not cause the document to be rejected.
%
%	SPEC		MANUAL		OUR SETTING
%	----		------		-----------
%	Top Margin	>= 1.0in	1.0in
% 	Bottom Margin	>= 1.0in	1.5in
%	Left Margin	>= 1.6in	1.0in
%	Right Margin	>= 1.0in	1.0in

\setlength {\topmargin}{0in}            % top margin    1.0 inch
\setlength {\textheight}{8.5in}         % bottom margin 1.5 inch
\setlength {\oddsidemargin}{0in}        % left margin   1.0 inch
\setlength {\evensidemargin}{0in}       % left margin   1.0 inch
\setlength {\textwidth}{6.5in}          % right margin  1.0 inch
\setlength {\footnotesep}{14pt}         % baseline skip for footnotes' 1st line
\setlength {\headheight}{0in}           % no header
\setlength {\headsep}{0in}              % no header separation

% LINE SPACING 

\singlespace                      	% single spacing for drafts

}	% end \pagesetup

%------------------------------------------------------------------------------
% 3. FRONT MATTER
%------------------------------------------------------------------------------
%
% The front matter includes
%	Abstract			required
%	Title Page			required
%	Copyright Statement
%	Preface or Foreword
%	Dedication
%	Acknowledgements
%	Table of Contents		required
%	List of Tables			required if any exist
%	List of Figures			required if any exist
%	List of Abbreviations
%
% We define parameters and then create the front matter section
% by section. 
% --------------------------------------------------------------------------

%------------------------------------------------------------------------------
% 	3.1. DEFINE PARAMETERS
% 		There are two kinds of commands that define parameters 
%		for the  front matter:  those  that  provide info (like 
%		\author or \abstractfile) and those that set flags (like 
%		\hascopyright).
%
% 		All commands that provide info redefine an internal command 
%		named  the same but with an initial at sign (e.g., \advisor 
%		redefined \@advisor).  This  idea is standard in LaTeX, so 
%		\author, \title, and \date are not defined here (the standards
% 		are used).
%  
% 		All commands that set flags are used to set the status of the 
%		corresponding ifthenelse command. The parameter must be true
%		or false, or else a `Undefined control sequence command' will 
%		be issued by TeX.
%------------------------------------------------------------------------------

% INFORMATION COMMANDS

\newcommand{\advisor}[1]{\renewcommand{\@advisor}{#1}}
\newcommand{\chairtitle}[1]{\renewcommand{\@chairtitle}{#1}}
\newcommand{\committee}[1]{\renewcommand{\@committee}{#1}}
\newcommand{\department}[1]{\renewcommand{\@department}{#1}}

\newcommand{\abtitle}[1]{\renewcommand{\@abtitle}{#1}}

\newcommand{\abstractfile}[1]{\renewcommand{\@abstractfile}{#1}}
\newcommand{\prefacefile}[1]{\renewcommand{\@prefacefile}{#1}}
\newcommand{\dedicationfile}[1]{\renewcommand{\@dedicationfile}{#1}}		
\newcommand{\acknowledgementsfile}[1]{\renewcommand{\@acknowledgementsfile}{#1}}	

% DEFAULT VALUES - RE-DEFINE THESE IN YOUR MAIN DOCUMENT

\renewcommand{\@author}{{\it Your Full Name}}
\renewcommand{\@title}{{\it Your Thesis Title}}
\newcommand{\@abtitle}{{\it Your Thesis Title}}
\renewcommand{\@date}{\number\year}
\newcommand{\@advisor}{{\it Academic title and name of advisor}}
\newcommand{\@chairtitle}{Chairman/Advisor}
\newcommand{\@committee}{{\it Academic title and name of members}}
\newcommand{\@department}{Department of Electrical and Computer Engineering}

 						% Corresponding file name
						% for user to set up:				
\newcommand{\@abstractfile}{abstract}			% abstract.tex
\newcommand{\@prefacefile}{preface}			% preface.tex
\newcommand{\@dedicationfile}{dedication}		% dedication.tex
\newcommand{\@acknowledgementsfile}{acknowledgements}	% acknowledgements.tex

% BOOLEAN SWITCHES		DEFAULT VALUE

\newboolean{hascopyright}	\setboolean{hascopyright}{true}
\newboolean{hasfigures} 	\setboolean{hasfigures}{true}
\newboolean{hastables}  	\setboolean{hastables}{true}

%------------------------------------------------------------------------------
% 	3.2. CREATE FRONT MATTER
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% 	\makefrontmatter
%        
% 	The \makefrontmatter command creates the front matter by conditionally
% 	invoking other commands:
%  
%       	\makeabstract, \maketitlepage, \makecopyrightpage, 
%		\makepreface, \makededication, \makeacknowledgements, 
%		\tableofcontents, \makelistoftables, \makelistoffigures, 
%		\makecommentpage.
%
% 	Page numbering is according to the manual in lowercase roman, arabic 
%	or none.
%------------------------------------------------------------------------------

\newcommand{\makefrontmatter}{

  \pagestyle {empty}				% No page numbers yet

  						% Required Sections:
  \makeabstract 				% Abstract
  \maketitlepage				% Title Page
  \makecopyrightpage				% Copyright statement

  \pagestyle {plain}				% Begin page numbers
  \pagenumbering {roman}			% with roman numerals
  \setcounter {page}{2}				% at page ii

							% Optional Sections:
  \@ifdefined {@prefacefile}{\makepreface}		% Preface
  \@ifdefined {@dedicationfile}{\makededication}	% Dedication
  \@ifdefined {@acknowledgementsfile}			% Acknowledgements
              {\makeacknowledgements}	

  \tableofcontents \newpage			% Table of Contents (always)
  \ifhastables \makelistoftables \fi		% List of Tables (if any)
  \ifhasfigures \makelistoffigures \fi		% List of Figures (if any)

  \pagenumbering {arabic}			% Begin arabic page numbers 
  \setcounter {page}{1}				% at page 1

}	% end \makefrontmatter

%------------------------------------------------------------------------------
% 	3.3. INDIVIDUAL FRONT MATTER SECTIONS
% 		Commands to create different parts of the front matter
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% ABSTRACT PAGE
% 	\makeabstract 
% 	Create the abstract page(s) including title, author, etc.
%------------------------------------------------------------------------------

\newcommand{\makeabstract}{

  \newpage
  \vspace*{0.5in}	% SKIP DOWN SO THAT FIRST LINE IS EVEN WITH FIRST
			% LINE OF TABLE OF CONTENTS 

  % Center the word ABSTRACT at the top of the page
  \begin{center} 
    \large \rm ABSTRACT   
  \end{center}
  \bigskip

  % Create the abstract page header information.
  {\singlespace			% control spacing with line breaks \\
  \noindent
  \begin{tabbing}
     Title of Dissertation \hspace*{-4pt}: \hspace{14pt} \= \@abtitle \\ \\
  \end{tabbing}
  \begin{center}
    \@author, Doctor of Philosophy, \@date 
  \end{center}
  \hugeskip
  \begin{tabbing}
    Dissertation directed by: \= \@advisor \\
	                      \> \@department
  \end{tabbing}
  }

  \hugeskip \bigskip 

  % include abstract from abstractfile now, after all the header info
  \@input{\@abstractfile}	
  \newpage
}	% end \makeabstract

%------------------------------------------------------------------------------
% TITLE PAGE
%	\maketitlepage
%	Create the title page including title, author, etc.
%------------------------------------------------------------------------------

\newcommand{\maketitlepage}{

  \newpage
  \vspace*{0.5in}

  \begin{center} 
    \large \rm \@title 
  \end{center}
  \bigskip

  \begin{center} 
    by \\ \@author 
  \end{center}
  \hugeskip

  {\singlespace
    \begin{center}
      Dissertation submitted to the Faculty of the Graduate School of the \\
      University of Maryland, College Park in partial fulfillment \\
      of the requirements for the degree of \\
      Doctor of Philosophy \\
      \@date
    \end{center} 
  }
 
  \hugeskip \hugeskip \hugeskip

  \noindent    
  Advisory Committee: 
  \bigskip

  {\singlespace
    \hspace{25pt}   
    \begin{tabular}{l}
      \@advisor, \@chairtitle \\ 
      \@committee 
    \end{tabular}
  }

  \newpage
}	% end \maketitlepage

%------------------------------------------------------------------------------
% COPYRIGHT PAGE
% 	\makecopyrightpage
%	create a copyright page or an empty page
%------------------------------------------------------------------------------

\newcommand{\makecopyrightpage}{
  \newpage

  \mbox{}\par\vfill

  \ifhascopyright
    \begin{center} \copyright Copyright by \\ \@author \\ \@date \end{center}
    \vfill
  \fi

\newpage
}

%------------------------------------------------------------------------------
% PREFACE
% 	\makepreface 
%	create a preface from file \@prefacefile
%------------------------------------------------------------------------------

\newcommand{\makepreface}{
  \newpage
  \vspace*{0.5in}

  \begin{center} \large \rm PREFACE \end{center}
  \bigskip

  \@input{\@prefacefile}

  \newpage
}

%------------------------------------------------------------------------------
% DEDICATION
% 	\makededication
%	create a dedication page from file \@dedicationfile
%------------------------------------------------------------------------------

\newcommand{\makededication}{
  \newpage
  \vspace*{0.7in}

  \begin{center} \large \rm DEDICATION \end{center}
  \bigskip

  \begin{center} \@input{\@dedicationfile} \end{center}		

  \newpage
}

%------------------------------------------------------------------------------
% ACKNOWLEDGEMENTS
% 	\makeacknowledgements
%	create an acknowledgements page from file \@acknowledgementsfile
%------------------------------------------------------------------------------

\newcommand{\makeacknowledgements}{
  \newpage
  \vspace*{0.5in}
 
  \begin{center} \large \rm ACKNOWLEDGEMENTS \end{center}
  \bigskip

  \@input{\@acknowledgementsfile}				% AJN 5/99

  \newpage
}

%------------------------------------------------------------------------------
% LIST OF TABLES
% 	\makelistoftables 
%	Create the list of tables.  This is the standard LaTeX list of
%	tables with a modified header line.  
%------------------------------------------------------------------------------

\newcommand{\makelistoftables}{
  \newpage
  \addcontentsline {toc}{chapter}{List of Tables}
  \listoftables
  \newpage
}

%------------------------------------------------------------------------------
% LIST OF FIGURES
% 	\makelistoffigures
%	Create the list of figures.  This is the standard LaTeX list of
%	figures with a modified header line.
%------------------------------------------------------------------------------

\newcommand{\makelistoffigures}{
  \newpage
  \addcontentsline {toc}{chapter}{List of Figures}
  \listoffigures
  \newpage
}

%------------------------------------------------------------------------------
% COMMENT PAGE
% 	\makecommentpage
%	create a (possibly empty) comment page
%------------------------------------------------------------------------------

\newcommand{\makecommentpage}{
  {\singlespace
  \begin{center}\@title \\[1ex]  \@author \\[1ex] \today \end{center}
  \par\vfill
  \@ifdefined{@comment}{\@comment}
  \par\vfill}
  \begin{center} \large\bf This comment page is not part of the dissertation.
  \\[3ex]
  \end{center}
  \newpage
}

%------------------------------------------------------------------------------
% 4. HEADINGS AND FORMATTING
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% HEADER LINES FOR SPECIAL PAGES
%	Header lines for TOC, LOF, LOT, and BIB must be centered and
%	all caps.  LaTeX uses 'CONTENTS' but we need 'TABLE OF CONTENTS'.  
%	LaTeX uses 'REFERENCES' but we need 'BIBLIOGRAPHY'.
%------------------------------------------------------------------------------

\renewcommand{\contentsname}{\centerline{\large \rm TABLE OF CONTENTS}}
\renewcommand{\listfigurename}{\centerline{\large \rm LIST OF FIGURES}}
\renewcommand{\listtablename}{\centerline{\large \rm LIST OF TABLES}}
\renewcommand{\bibname}{\centerline{\large \rm BIBLIOGRAPHY}}

%------------------------------------------------------------------------------
% 5. UTILITY COMMANDS
%------------------------------------------------------------------------------

%------------------------------------------------------------------------------
% 	5.1. LINE SPACING
%	 	The \renewcommand{\baselinestretch}{XXX} command is long.
%		So, we define the easier and more intuitive \singlespace and
%		\doublespace, as well as \spacing for arbitrary line spacing.
%		A font changing command is needed for the change to take 
%		effect, so the commands \large \normalsize are included 
%		(but cancel each other out).  
%------------------------------------------------------------------------------

% The baselinestretch for double spacing is 1.667.  I don't know why it
% is not 2.000.  However, this is how it has been done.

\newcommand{\singlespace}
  {\renewcommand{\baselinestretch}{1.0} \large \normalsize}
\newcommand{\doublespace}
  {\renewcommand{\baselinestretch}{1.667} \large \normalsize}
\newcommand{\spacing}[1]
  {\renewcommand{\baselinestretch}{#1}\large\normalsize}

% \hugeskip - skip twice as much as the TeX command \bigskip
\newcommand{\hugeskip}{\vskip 24pt plus 8pt minus 8pt}

%------------------------------------------------------------------------------
% 	5.2. CROSS REFERENCES
%		Facilitate cross references by creating easy to use commands.
%------------------------------------------------------------------------------

\newcommand{\Chapter}[1]{Chapter~\ref{#1}}
\newcommand{\Chapters}[2]{Chapters~\ref{#1} and~\ref{#2}}
\newcommand{\Section}[1]{Section~\ref{#1}}
\newcommand{\Sections}[2]{Sections~\ref{#1} and~\ref{#2}}
\newcommand{\Appendix}[1]{Appendix~\ref{#1}}
\newcommand{\Figure}[1]{Figure~\ref{#1}}
\newcommand{\Figures}[2]{Figures~\ref{#1} and~\ref{#2}}
\newcommand{\Table}[1]{Table~\ref{#1}}
\newcommand{\Tables}[2]{Tables~\ref{#1} and~\ref{#2}}
\newcommand{\Definition}[1]{Definition~\ref{#1}}
\newcommand{\Definitions}[2]{Definitions~\ref{#1} and~\ref{#2}}
\newcommand{\Remark}[1]{Remark~\ref{#1}}
\newcommand{\Example}[1]{Example~\ref{#1}}
\newcommand{\Theorem}[1]{Theorem~\ref{#1}}
\newcommand{\Lemma}[1]{Lemma~\ref{#1}}
\newcommand{\Corollary}[1]{Corollary~\ref{#1}}
\newcommand{\Algorithm}[1]{Algorithm~\ref{#1}}
\newcommand{\Algorithms}[2]{Algorithms~\ref{#1} and~\ref{#2}}
\newcommand{\Proposition}[1]{Proposition~\ref{#1}}
\newcommand{\Equation}[1]{Equation~(\ref{#1})}
\newcommand{\Equations}[2]{Equations~(\ref{#1}) and~(\ref{#2})}
\newcommand{\page}[1]{page~\pageref{#1}}

%------------------------------------------------------------------------------
%	5.3. LOGICAL
%------------------------------------------------------------------------------

% \@ifdefined - logical opposite of \ifundefined which is provided by LaTeX
\newcommand{\@ifdefined}[2]{\@ifundefined{#1}{}{#2}}

%------------------------------------------------------------------------------

%% End of file `umcp-thesis-draft.cls'.



